pub enum CompressedWriter {
Gzip(GzEncoder<File>),
Zlib(ZlibEncoder<File>),
Zstd(Encoder<'static, File>),
Brotli(CompressorWriter<File>),
}Expand description
Encoder wrapper that provides a uniform interface for different compression formats.
This enum wraps the various compression encoders so we can treat them uniformly in the append-to-compressed-archive flow.
Variants
Gzip(GzEncoder<File>)
Zlib(ZlibEncoder<File>)
Zstd(Encoder<'static, File>)
Brotli(CompressorWriter<File>)
Implementations
Sourceimpl CompressedWriter
impl CompressedWriter
Sourcepub fn new(format: CompressionFormat, file: File) -> Result<Self, Diagnostic>
pub fn new(format: CompressionFormat, file: File) -> Result<Self, Diagnostic>
Create a new compressed writer for the given format and file.
Sourcepub fn finish(self) -> Result<(), Diagnostic>
pub fn finish(self) -> Result<(), Diagnostic>
Finish compression and return any errors.
This must be called before the file is closed to ensure all compressed data is flushed.