pub struct Header {
pub file_type: String,
pub version: u32,
pub created: DateTime<Utc>,
pub source: Option<String>,
pub initial: Value,
pub metadata: Option<Value>,
}Fields
file_type: StringType identifier for magic file detection. We put this first to act as a “poor man’s magic file number detection” when the archive file has an unexpected extension. This helps avoid issues like the Elm compiler that requires specific file extensions (e.g., .js) which doesn’t play nice with build systems using temporary files with arbitrary suffixes. By putting this key first, we can detect archive files even when they have non-standard extensions like .tmp appended by build tools.
version: u32created: DateTime<Utc>source: Option<String>initial: Valuemetadata: Option<Value>Implementations